@@ -93,13 +93,13 @@ class GuestNetworkDaemon(Collector):
         except KeyError:
             return None
         try:
-            output = Popen([prog, name], stdout=PIPE).communicate()[0]
+            output = Popen([prog, name], stdout=PIPE).communicate()[0].decode("utf-8")
         except OSError as e:
             self.logger.warn("Cannot call name-to-ip-helper: %s", e.strerror)
             return None
         matches = re.findall(r"^(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})",
                              output, re.M)
-        if len(matches) is not 1:
+        if len(matches) != 1:
             self.logger.warn("Output from name-to-ip-helper %s is not an IP " \
                              "address. (output = '%s')", name, output)
             return None
