@@ -13,13 +13,16 @@
 # You should have received a copy of the GNU General Public
 # License along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-import logging
+from __future__ import division
 
+import logging
+from functools import total_ordering
 import re
-from spark import GenericScanner, GenericParser
+from .spark import GenericScanner, GenericParser
 
 class PolicyError(Exception): pass
 
+@total_ordering
 class Token(object):
     def __init__(self, kind, value=None, line=None):
         self.kind = kind
@@ -29,8 +32,14 @@ class Token(object):
         else:
             self.value = value
 
-    def __cmp__(self, rhs):
-        return cmp(self.kind, rhs)
+    def __eq__(self, rhs):
+        return self.kind == rhs
+
+    def __ne__(self, rhs):
+        return not self == rhs
+
+    def __lt__(self, rhs):
+        return self.kind < rhs
 
     def __repr__(self):
         return '[%s %s]' % (self.kind, self.value)
@@ -88,11 +97,11 @@ class Scanner(GenericScanner):
         self.rv.append(NumericToken('float', s, line))
 
     def t_integer(self, s, line):
-        r' -?(0(?![0-9Xx])|[1-9][0-9]*)(?![0-9eE]) '
+        r' -?(0(?![0-9oXx])|[1-9][0-9]*)(?![0-9eE]) '
         self.rv.append(NumericToken('integer', s, line))
 
     def t_integer_with_exponent(self, s, line):
-        r' -?(0(?![0-9Xx])|[1-9][0-9]*)[Ee][+-]?[0-9]+ '
+        r' -?(0(?![0-9oXx])|[1-9][0-9]*)[Ee][+-]?[0-9]+ '
         # Python only recognizes scientific notation on float types
         self.rv.append(NumericToken('float', s, line))
 
@@ -101,7 +110,7 @@ class Scanner(GenericScanner):
         self.rv.append(NumericToken('hex', s, line))
 
     def t_octal(self, s, line):
-        r' 0[0-9]+ '
+        r' 0o[0-9]+ '
         self.rv.append(NumericToken('octal', s, line))
 
     def t_builtin_op(self, s, line):
@@ -194,7 +203,7 @@ class GenericEvaluator(object):
         eg. << must appear before <
         """
         return sorted(self.operator_map.keys(),
-                      cmp = lambda x,y: cmp(len(x), len(y)),
+                      key = lambda x:len(x),
                       reverse = True)
 
     def parse_doc(self, doc):
@@ -215,7 +224,7 @@ class GenericEvaluator(object):
     def _dispatch(self, fn, args, line):
         doc = fn.__doc__
         if doc == None:
-            args = map(self.eval, args)
+            args = list(map(self.eval, args))
         else:
             types = self.parse_doc(doc)
 
@@ -272,7 +281,7 @@ class GenericEvaluator(object):
 
         node = code[0]
         if not isinstance(node, Token):
-            print code
+            print(code)
             raise PolicyError('Expected simple token as arg 1')
 
         if node.kind == 'symbol':
@@ -285,7 +294,7 @@ class GenericEvaluator(object):
 
         func = self.stack.get(name, line=node.line, allow_undefined=True)
         if func is not None:
-            args = map(self.eval, code[1:])
+            args = list(map(self.eval, code[1:]))
             return func(*args)
         elif hasattr(self, 'c_%s' % name):
             return self._dispatch(getattr(self, 'c_%s' % name), code[1:], line=node.line)
@@ -310,7 +319,7 @@ class VariableStack(object):
         parts = name.split('.')
         obj = parts[0]
         for scope in self.stack:
-            if scope.has_key(obj):
+            if obj in scope:
                 if len(parts) > 1:
                     if hasattr(scope[obj], parts[1]):
                         return getattr(scope[obj], parts[1])
@@ -326,7 +335,7 @@ class VariableStack(object):
             return self.stack[0][name]
 
         for scope in self.stack:
-            if scope.has_key(name):
+            if name in scope:
                 scope[name] = value
                 return value
 
@@ -369,7 +378,7 @@ class Evaluator(GenericEvaluator):
 
     def default(self, name, args, line):
         if name == 'eval':
-            return map(self.eval, args)[-1]
+            return list(map(self.eval, args))[-1]
 
         params, code = self.funcs[name]
         if len(params) != len(args):
@@ -546,13 +555,13 @@ def eval(e, string):
 
 def repl(e):
     while True:
-        print '>>>',
+        print('>>>')
         try:
-            string = raw_input()
+            string = input()
         except EOFError:
             break
 
-        print eval(e, string)[0]
+        print(eval(e, string)[0])
 
 if __name__ == '__main__':
     import sys
@@ -567,6 +576,6 @@ if __name__ == '__main__':
             f.close()
         results = eval(e, lines)
         for result in results:
-            print result
+            print(result)
     else:
         repl(e)
