@@ -93,7 +93,7 @@ class MOM:
                 setattr(self, funcName, funcObj)
 
     def _load_config(self, fname, overrides):
-        self.config = configparser.SafeConfigParser()
+        self.config = configparser.ConfigParser()
 
         # Set built-in defaults
         self.config.add_section('main')
@@ -213,8 +213,8 @@ class MOM:
         Check to make sure a list of expected threads are still alive
         """
         for t in threads:
-            if not t.isAlive():
-                self.logger.error("Thread '%s' has exited" % t.getName())
+            if not t.is_alive():
+                self.logger.error("Thread '%s' has exited" % t.name)
                 return False
         return True
 
@@ -222,7 +222,7 @@ class MOM:
         """
         Join a thread only if it is still running
         """
-        if t.isAlive():
+        if t.is_alive():
             t.join(timeout)
 
     def get_hypervisor_interface(self):
